==> freecad_0.18.4+dfsg2.orig.tar.xz: FreeCAD-0.18.4/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_kab.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="kab" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Créer une feuille de calcul</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Créer une nouvelle feuille de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Aligner en bas</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Aligne le contenu des cellules sélectionnées en bas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Alignement au centre</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Aligne le contenu des cellules sélectionnées au centre</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Alignement à gauche</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Aligne le contenu des cellules sélectionnées à gauche</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Alignement à droite</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Aligne le contenu des cellules sélectionnées à droite</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Alignement en haut</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Aligne le contenu des cellules sélectionnées en haut</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Alignement vertical au centre</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exporter la feuille de calcul</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exporter la feuille de calcul vers un fichier CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importer une feuille de calcul</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importer un fichier CSV dans une feuille de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Fusionner des cellules</translation>
    </message>
    <message>
      <source>Merge selected cells in spreadsheet</source>
      <translation>Fusionner les cellules sélectionnées dans la feuille de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Alias de la cellule sélectionnée</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Diviser la cellule</translation>
    </message>
    <message>
      <source>Split previously merged cells in spreadsheet</source>
      <translation>Diviser les cellules précédemment fusionnées dans la feuille de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Texte en gras</translation>
    </message>
    <message>
      <source>Set bold text in selected cells</source>
      <translation>Mettre le texte en gras dans les cellules sélectionnées</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Texte en italique</translation>
    </message>
    <message>
      <source>Set italic text in selected cells</source>
      <translation>Mettre le texte en italique dans les cellules sélectionnées</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Texte souligné</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Propriétés de la cellule</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Couleur</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Aḍris</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Arrière-plan</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Alignement</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Gauche</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Centre</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Droit</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Dessus</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Dessous</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>a&amp;ɣanib</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Gras</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Italique</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Souligné</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Affichage unités</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Texte unité</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation type="unfinished">A&amp;lias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias pour cette cellule</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Tous (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importer un fichier</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exporter un fichier</translation>
    </message>
    <message>
      <source>Cell contents</source>
      <translation>Contenu de la cellule</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Voir la feuille de calcul</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation type="unfinished">Set cell(s) foreground color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) foreground color</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation type="unfinished">Set cell(s) background color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) background color</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Noir</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Blanc</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Rouge</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Rouge foncé</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Vert</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Vert foncé</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Bleu</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Bleu foncé</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation type="unfinished">Cyan</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Cyan foncé</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation type="unfinished">Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Magenta foncé</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Jaune</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Jaune foncé</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Gris</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Gris foncé</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Gris clair</translation>
    </message>
    <message>
      <source>Custom</source>
      <translation>Personnalisé</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Forme</translation>
    </message>
    <message>
      <source>&amp;Contents</source>
      <translation>&amp;Contenu</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Sans nom</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Insérer des lignes</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Supprimer des lignes</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Insérer des colonnes</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Supprimer des colonnes</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Propriétés...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
  </context>
</TS>

==> freecad_0.19.1+dfsg1.orig.tar.xz: FreeCAD-0.19.1/src/Mod/Spreadsheet/Gui/Resources/translations/Spreadsheet_kab.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="kab" sourcelanguage="en">
  <context>
    <name>CmdCreateSpreadsheet</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Create spreadsheet</source>
      <translation>Créer une feuille de calcul</translation>
    </message>
    <message>
      <source>Create a new spreadsheet</source>
      <translation>Créer une nouvelle feuille de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignBottom</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Align bottom</source>
      <translation>Aligner en bas</translation>
    </message>
    <message>
      <source>Bottom-align contents of selected cells</source>
      <translation>Aligne le contenu des cellules sélectionnées en bas</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Align center</source>
      <translation>Alignement au centre</translation>
    </message>
    <message>
      <source>Center-align contents of selected cells</source>
      <translation>Aligne le contenu des cellules sélectionnées au centre</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignLeft</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Align left</source>
      <translation>Alignement à gauche</translation>
    </message>
    <message>
      <source>Left-align contents of selected cells</source>
      <translation>Aligne le contenu des cellules sélectionnées à gauche</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignRight</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Align right</source>
      <translation>Alignement à droite</translation>
    </message>
    <message>
      <source>Right-align contents of selected cells</source>
      <translation>Aligne le contenu des cellules sélectionnées à droite</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignTop</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Align top</source>
      <translation>Alignement en haut</translation>
    </message>
    <message>
      <source>Top-align contents of selected cells</source>
      <translation>Aligne le contenu des cellules sélectionnées en haut</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetAlignVCenter</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Vertically center-align</source>
      <translation>Alignement vertical au centre</translation>
    </message>
    <message>
      <source>Vertically center-align contents of selected cells</source>
      <translation type="unfinished">Vertically center-align contents of selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetExport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Export spreadsheet</source>
      <translation>Exporter la feuille de calcul</translation>
    </message>
    <message>
      <source>Export spreadsheet to CSV file</source>
      <translation>Exporter la feuille de calcul vers un fichier CSV</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetImport</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Import spreadsheet</source>
      <translation>Importer une feuille de calcul</translation>
    </message>
    <message>
      <source>Import CSV file into spreadsheet</source>
      <translation>Importer un fichier CSV dans une feuille de calcul</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetMergeCells</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Merge cells</source>
      <translation>Fusionner des cellules</translation>
    </message>
    <message>
      <source>Merge selected cells</source>
      <translation type="unfinished">Merge selected cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSetAlias</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Set alias</source>
      <translation>Alias</translation>
    </message>
    <message>
      <source>Set alias for selected cell</source>
      <translation>Alias de la cellule sélectionnée</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetSplitCell</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Diviser la cellule</translation>
    </message>
    <message>
      <source>Split previously merged cells</source>
      <translation type="unfinished">Split previously merged cells</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleBold</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Bold text</source>
      <translation>Texte en gras</translation>
    </message>
    <message>
      <source>Set text in selected cells bold</source>
      <translation type="unfinished">Set text in selected cells bold</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleItalic</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Italic text</source>
      <translation>Texte en italique</translation>
    </message>
    <message>
      <source>Set text in selected cells italic</source>
      <translation type="unfinished">Set text in selected cells italic</translation>
    </message>
  </context>
  <context>
    <name>CmdSpreadsheetStyleUnderline</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Underline text</source>
      <translation>Texte souligné</translation>
    </message>
    <message>
      <source>Underline text in selected cells</source>
      <translation type="unfinished">Underline text in selected cells</translation>
    </message>
  </context>
  <context>
    <name>ColorPickerPopup</name>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <source>Merge cells</source>
      <translation>Fusionner des cellules</translation>
    </message>
    <message>
      <source>Split cell</source>
      <translation>Diviser la cellule</translation>
    </message>
    <message>
      <source>Left-align cell</source>
      <translation type="unfinished">Left-align cell</translation>
    </message>
    <message>
      <source>Center cell</source>
      <translation type="unfinished">Center cell</translation>
    </message>
    <message>
      <source>Right-align cell</source>
      <translation type="unfinished">Right-align cell</translation>
    </message>
    <message>
      <source>Top-align cell</source>
      <translation type="unfinished">Top-align cell</translation>
    </message>
    <message>
      <source>Bottom-align cell</source>
      <translation type="unfinished">Bottom-align cell</translation>
    </message>
    <message>
      <source>Vertically center cells</source>
      <translation type="unfinished">Vertically center cells</translation>
    </message>
    <message>
      <source>Set bold text</source>
      <translation type="unfinished">Set bold text</translation>
    </message>
    <message>
      <source>Set italic text</source>
      <translation type="unfinished">Set italic text</translation>
    </message>
    <message>
      <source>Set underline text</source>
      <translation type="unfinished">Set underline text</translation>
    </message>
    <message>
      <source>Create Spreadsheet</source>
      <translation type="unfinished">Create Spreadsheet</translation>
    </message>
    <message>
      <source>Set cell properties</source>
      <translation type="unfinished">Set cell properties</translation>
    </message>
    <message>
      <source>Edit cell</source>
      <translation type="unfinished">Edit cell</translation>
    </message>
    <message>
      <source>Insert rows</source>
      <translation>Insérer des lignes</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Supprimer des lignes</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Insérer des colonnes</translation>
    </message>
    <message>
      <source>Clear cell(s)</source>
      <translation type="unfinished">Clear cell(s)</translation>
    </message>
    <message>
      <source>Set foreground color</source>
      <translation type="unfinished">Set foreground color</translation>
    </message>
    <message>
      <source>Set background color</source>
      <translation type="unfinished">Set background color</translation>
    </message>
  </context>
  <context>
    <name>PropertiesDialog</name>
    <message>
      <source>Cell properties</source>
      <translation>Propriétés de la cellule</translation>
    </message>
    <message>
      <source>&amp;Color</source>
      <translation>&amp;Couleur</translation>
    </message>
    <message>
      <source>Text</source>
      <translation>Aḍris</translation>
    </message>
    <message>
      <source>Background</source>
      <translation>Arrière-plan</translation>
    </message>
    <message>
      <source>&amp;Alignment</source>
      <translation>&amp;Alignement</translation>
    </message>
    <message>
      <source>Horizontal</source>
      <translation type="unfinished">Horizontal</translation>
    </message>
    <message>
      <source>Left</source>
      <translation>Gauche</translation>
    </message>
    <message>
      <source>Center</source>
      <translation>Centre</translation>
    </message>
    <message>
      <source>Right</source>
      <translation>Droit</translation>
    </message>
    <message>
      <source>Vertical</source>
      <translation type="unfinished">Vertical</translation>
    </message>
    <message>
      <source>Top</source>
      <translation>Dessus</translation>
    </message>
    <message>
      <source>Bottom</source>
      <translation>Dessous</translation>
    </message>
    <message>
      <source>&amp;Style</source>
      <translation>a&amp;ɣanib</translation>
    </message>
    <message>
      <source>Bold</source>
      <translation>Gras</translation>
    </message>
    <message>
      <source>Italic</source>
      <translation>Italique</translation>
    </message>
    <message>
      <source>Underline</source>
      <translation>Souligné</translation>
    </message>
    <message>
      <source>&amp;Display unit</source>
      <translation>&amp;Affichage unités</translation>
    </message>
    <message>
      <source>Unit string</source>
      <translation>Texte unité</translation>
    </message>
    <message>
      <source>A&amp;lias</source>
      <translation type="unfinished">A&amp;lias</translation>
    </message>
    <message>
      <source>Alias for this cell</source>
      <translation>Alias pour cette cellule</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>All (*)</source>
      <translation>Tous (*)</translation>
    </message>
    <message>
      <source>Import file</source>
      <translation>Importer un fichier</translation>
    </message>
    <message>
      <source>Export file</source>
      <translation>Exporter un fichier</translation>
    </message>
    <message>
      <source>Show spreadsheet</source>
      <translation>Voir la feuille de calcul</translation>
    </message>
    <message>
      <source>Set cell(s) foreground color</source>
      <translation type="unfinished">Set cell(s) foreground color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) foreground color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) foreground color</translation>
    </message>
    <message>
      <source>Set cell(s) background color</source>
      <translation type="unfinished">Set cell(s) background color</translation>
    </message>
    <message>
      <source>Sets the Spreadsheet cell(s) background color</source>
      <translation type="unfinished">Sets the Spreadsheet cell(s) background color</translation>
    </message>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
    <message>
      <source>Spreadsheet does not support range selection when pasting.
Please select one cell only.</source>
      <translation type="unfinished">Spreadsheet does not support range selection when pasting.
Please select one cell only.</translation>
    </message>
    <message>
      <source>Copy &amp; Paste failed</source>
      <translation type="unfinished">Copy &amp; Paste failed</translation>
    </message>
    <message>
      <source>Alias contains invalid characters!</source>
      <translation type="unfinished">Alias contains invalid characters!</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>QtColorPicker</name>
    <message>
      <source>Black</source>
      <translation>Noir</translation>
    </message>
    <message>
      <source>White</source>
      <translation>Blanc</translation>
    </message>
    <message>
      <source>Red</source>
      <translation>Rouge</translation>
    </message>
    <message>
      <source>Dark red</source>
      <translation>Rouge foncé</translation>
    </message>
    <message>
      <source>Green</source>
      <translation>Vert</translation>
    </message>
    <message>
      <source>Dark green</source>
      <translation>Vert foncé</translation>
    </message>
    <message>
      <source>Blue</source>
      <translation>Bleu</translation>
    </message>
    <message>
      <source>Dark blue</source>
      <translation>Bleu foncé</translation>
    </message>
    <message>
      <source>Cyan</source>
      <translation type="unfinished">Cyan</translation>
    </message>
    <message>
      <source>Dark cyan</source>
      <translation>Cyan foncé</translation>
    </message>
    <message>
      <source>Magenta</source>
      <translation type="unfinished">Magenta</translation>
    </message>
    <message>
      <source>Dark magenta</source>
      <translation>Magenta foncé</translation>
    </message>
    <message>
      <source>Yellow</source>
      <translation>Jaune</translation>
    </message>
    <message>
      <source>Dark yellow</source>
      <translation>Jaune foncé</translation>
    </message>
    <message>
      <source>Gray</source>
      <translation>Gris</translation>
    </message>
    <message>
      <source>Dark gray</source>
      <translation>Gris foncé</translation>
    </message>
    <message>
      <source>Light gray</source>
      <translation>Gris clair</translation>
    </message>
    <message>
      <source>Custom Color</source>
      <translation type="unfinished">Custom Color</translation>
    </message>
  </context>
  <context>
    <name>Sheet</name>
    <message>
      <source>Form</source>
      <translation>Forme</translation>
    </message>
    <message>
      <source>&amp;Content:</source>
      <translation type="unfinished">&amp;Content:</translation>
    </message>
    <message>
      <source>&amp;Alias:</source>
      <translation type="unfinished">&amp;Alias:</translation>
    </message>
    <message>
      <source>Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</source>
      <translation type="unfinished">Refer to cell by alias, for example
Spreadsheet.my_alias_name instead of Spreadsheet.B1</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::Module</name>
    <message>
      <source>Unnamed</source>
      <translation>Sans nom</translation>
    </message>
  </context>
  <context>
    <name>SpreadsheetGui::SheetTableView</name>
    <message>
      <source>Insert rows</source>
      <translation>Insérer des lignes</translation>
    </message>
    <message>
      <source>Remove rows</source>
      <translation>Supprimer des lignes</translation>
    </message>
    <message>
      <source>Insert columns</source>
      <translation>Insérer des colonnes</translation>
    </message>
    <message>
      <source>Remove columns</source>
      <translation>Supprimer des colonnes</translation>
    </message>
    <message>
      <source>Properties...</source>
      <translation>Propriétés...</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <source>Spreadsheet</source>
      <translation>Tableur</translation>
    </message>
  </context>
</TS>
